## cdist-type__consul_watch_checks(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__consul_watch_checks - manages consul checks watches

## 2. DESCRIPTION

Generate and deploy watch definitions of type checks for a consul agent. See http://www.consul.io/docs/agent/watches.html for parameter documentation.

## 3. REQUIRED PARAMETERS

handler
  the handler to invoke when the data view updates

## 4. OPTIONAL PARAMETERS

datacenter
  can be provided to override the agent’s default datacenter
filter-service
  filter to a specific service. Conflicts with --filter-state.
filter-state
  filter to a specific state. Conflicts with --filter-service.
state
  if this watch is present or absent. Defaults to present.
token
  can be provided to override the agent’s default ACL token

## 5. EXAMPLES

    __consul_watch_checks some-id \
       --handler /usr/bin/my-handler.sh

    __consul_watch_checks some-id \
       --filter-service consul \
       --handler /usr/bin/my-handler.sh

    __consul_watch_checks some-id \
       --filter-state passing \
       --handler /usr/bin/my-handler.sh

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__consul_agent(7)
- http://www.consul.io/docs/agent/watches.html

## 7. COPYING

Copyright (C) 2015 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).